package logic

import (
	"context"
	"fusenapi/constants"
	"fusenapi/utils/auth"
	"fusenapi/utils/basic"

	"fusenapi/server/websocket/internal/svc"
	"fusenapi/server/websocket/internal/types"

	"github.com/zeromicro/go-zero/core/logx"
)

type CommonNotifyLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewCommonNotifyLogic(ctx context.Context, svcCtx *svc.ServiceContext) *CommonNotifyLogic {
	return &CommonNotifyLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

// 处理进入前逻辑w,r
// func (l *CommonNotifyLogic) BeforeLogic(w http.ResponseWriter, r *http.Request) {
// }

func (l *CommonNotifyLogic) CommonNotify(req *types.CommonNotifyReq, userinfo *auth.UserInfo) (resp *basic.Response) {
	//websocket连接id不能为空
	if req.Wid == "" {
		return resp.SetStatusWithMessage(basic.CodeRequestParamsErr, "websocket connect id is empty")
	}
	//查询websocket连接
	value, ok := mapConnPool.Load(req.Wid)
	if !ok {
		return resp.SetStatusWithMessage(basic.CodeOK, "success,but connection is not found")
	}
	//断言连接
	ws, ok := value.(wsConnectItem)
	if !ok {
		logx.Error("渲染回调断言websocket连接失败")
		return resp.SetStatusWithMessage(basic.CodeServiceErr, "断言连接错误")
	}
	ws.sendToOutChan(ws.respondDataFormat(constants.WEBSOCKET_COMMON_NOTIFY, req.Data))
	return resp.SetStatusWithMessage(basic.CodeOK, "success")
}

// 处理逻辑后 w,r 如:重定向, resp 必须重新处理
// func (l *CommonNotifyLogic) AfterLogic(w http.ResponseWriter, r *http.Request, resp *basic.Response) {
// // httpx.OkJsonCtx(r.Context(), w, resp)
// }
